@@ -27,8 +27,6 @@
 class QTimer;
 class CheckableStringListModel;
 
-class QTextBrowser;
-class KTextBrowser;
 class QGraphicsProxyWidget;
 class QGraphicsLinearLayout;
 
@@ -36,6 +34,7 @@ namespace Plasma
 {
     class IconWidget;
     class LineEdit;
+    class TextBrowser;
 }
 
 class DictApplet: public Plasma::PopupApplet
@@ -44,6 +43,7 @@ class DictApplet: public Plasma::PopupApplet
     public:
         DictApplet(QObject *parent, const QVariantList &args);
         ~DictApplet();
+        void init();
 
         QGraphicsWidget *graphicsWidget();
         void setPath(const QString&);
@@ -56,9 +56,11 @@ class DictApplet: public Plasma::PopupApplet
     protected slots:
         void define();
         void configAccepted();
+        void focusEditor();
 
     protected:
         void createConfigurationInterface(KConfigDialog *parent);
+        void popupEvent(bool shown);
 
     private:
         QString m_source;
@@ -71,8 +73,7 @@ class DictApplet: public Plasma::PopupApplet
         Plasma::LineEdit *m_wordEdit;
         //Plasma::Flash *m_flash;
 //         QTextBrowser* m_defBrowser;
-        KTextBrowser* m_defBrowser;
-        QGraphicsProxyWidget *m_defBrowserProxy;
+        Plasma::TextBrowser* m_defBrowser;
         Plasma::IconWidget *m_icon;
 
 //         QList< QPair<QString, bool> > m_dicts;
