@@ -20,7 +20,7 @@
 #include "konqprofilesapplet.h"
 #include <QTreeView>
 #include <KStandardDirs>
-#include <plasma/widgets/icon.h>
+#include <plasma/widgets/iconwidget.h>
 #include <QGraphicsProxyWidget>
 #include <QGraphicsLinearLayout>
 #include <QStandardItemModel>
@@ -32,7 +32,7 @@
 #include <kio/global.h>
 
 KonqProfilesApplet::KonqProfilesApplet(QObject *parent, const QVariantList &args)
-    : PlasmaAppletDialog(parent, args), m_listView( 0 )
+    : Plasma::PopupApplet(parent, args), m_listView( 0 )
 {
     KDirWatch *dirwatch = new KDirWatch( this );
     QStringList lst = KGlobal::dirs()->findDirs( "data", "konqueror/profiles/" );
@@ -41,22 +41,20 @@ KonqProfilesApplet::KonqProfilesApplet(QObject *parent, const QVariantList &args
         dirwatch->addDir( lst[i] );
     }
     connect( dirwatch, SIGNAL(dirty (const QString &) ), this, SLOT( slotUpdateKonqProfiles() ) );
+    setPopupIcon("konqueror");
 }
 
 KonqProfilesApplet::~KonqProfilesApplet()
 {
-}
-
-void KonqProfilesApplet::initialize()
-{
-    m_icon = new Plasma::Icon(KIcon("konqueror"), QString(), this);
+    delete m_listView;
 }
 
 QWidget *KonqProfilesApplet::widget()
 {
     if ( !m_listView )
     {
-        m_listView= new QTreeView(m_dialog);
+        m_listView= new QTreeView();
+        m_listView->setAttribute(Qt::WA_NoSystemBackground);
         m_listView->setEditTriggers( QAbstractItemView::NoEditTriggers );
         m_listView->setRootIsDecorated(false);
         m_listView->setHeaderHidden(true);
@@ -88,8 +86,8 @@ void KonqProfilesApplet::slotUpdateKonqProfiles()
 
 void KonqProfilesApplet::initSessionFiles()
 {
-    QStringList list = KGlobal::dirs()->findAllResources( "data", "konqueror/profiles/*", KStandardDirs::NoDuplicates );
-    for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it)
+    const QStringList list = KGlobal::dirs()->findAllResources( "data", "konqueror/profiles/*", KStandardDirs::NoDuplicates );
+    for (QStringList::ConstIterator it = list.constBegin(); it != list.constEnd(); ++it)
     {
         QFileInfo info( *it );
         QString profileName = KIO::decodeFileName( info.baseName() );
@@ -112,14 +110,11 @@ void KonqProfilesApplet::initSessionFiles()
 
 void KonqProfilesApplet::slotOnItemClicked(const QModelIndex &index)
 {
-    if ( m_closePopup )
-        m_dialog->hide();
+    hidePopup();
     QStringList args;
     args<<"--profile"<<index.data(ProfilesName).toString();
     KToolInvocation::kdeinitExec("konqueror", args);
-
 }
 
-
-
 #include "konqprofilesapplet.moc"
+
