@@ -21,7 +21,7 @@
 #ifndef QT_DISPLAY
 #define QT_DISPLAY
 
-#include "config-lancelot.h"
+#include <config-lancelot.h>
 
 #ifdef LANCELOT_HAVE_COMPOSITING
 
@@ -51,7 +51,7 @@
 
 class QtDisplay {
 public:
-    QtDisplay(char * display = 0, int screen = 0);
+    explicit QtDisplay(char * display = 0, int screen = 0);
     virtual ~QtDisplay();
     virtual void testDisplay();
     void setupXRender();
