@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007 Ivan Cukic <ivan.cukic+kde@gmail.com>
+ *   Copyright (C) 2009 Ivan Cukic <ivan.cukic+kde@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License version 2,
@@ -18,7 +18,6 @@
  */
 
 #include "LancelotPart.h"
-#include <KDebug>
 #include <KIcon>
 #include <KMimeType>
 #include <KUrl>
@@ -26,6 +25,7 @@
 #include <QGraphicsLayout>
 #include <QDataStream>
 #include <plasma/framesvg.h>
+#include <plasma/widgets/iconwidget.h>
 
 #include "../models/BaseModel.h"
 #include "../models/Devices.h"
@@ -42,120 +42,12 @@
 #include "../models/MessagesKmail.h"
 #include "../Serializator.h"
 
-class PopupGraphicsView : public QGraphicsView {
-public:
-    PopupGraphicsView(
-        QGraphicsScene * scene,
-        Lancelot::ActionListView * list,
-        QWidget * parent
-    ) : QGraphicsView(scene, parent), m_list(list)
-    {
-        setWindowFlags(Qt::FramelessWindowHint);
-        setFrameStyle(QFrame::NoFrame);
-        setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-        setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+#define ACTIVATION_TIME 300
 
-        setCacheMode(QGraphicsView::CacheBackground);
-
-        m_bg.setImagePath("dialogs/background");
-        m_bg.setEnabledBorders(Plasma::FrameSvg::NoBorder);
-    }
-
-    void drawBackground(QPainter * painter, const QRectF & rect)
-    {
-        Q_UNUSED(rect);
-        painter->setCompositionMode(QPainter::CompositionMode_Source);
-        painter->fillRect(QRectF(rect.x()-2,rect.y()-2,rect.width()+2,rect.height()+2).toRect(), Qt::transparent);
-        m_bg.resizeFrame(rect.size());
-        m_bg.paintFrame(painter);
-    }
-
-    virtual void setVisible(bool visible)
-    {
-        if (visible) {
-            m_list->setPreferredSize(QSizeF(size()));
-            m_list->setMinimumSize(QSizeF(size()));
-            m_list->setGeometry(QRectF(
-                        QPointF(),
-                        QSizeF(size())
-                   ));
-        }
-        QGraphicsView::setVisible(visible);
-    }
-
-private:
-    Lancelot::ActionListView * m_list;
-    Plasma::FrameSvg m_bg;
-
-};
-
-class FullLayout: public QGraphicsLayout {
-public:
-    FullLayout(QGraphicsLayoutItem * parent = 0)
-        : QGraphicsLayout(parent)
-    {
-    }
-
-    virtual int count() const
-    {
-        return m_items.size();
-    }
-
-    void setGeometry(const QRectF & rect)
-    {
-        QGraphicsLayout::setGeometry(rect);
-        invalidate();
-    }
-
-    virtual void invalidate()
-    {
-        foreach (QGraphicsLayoutItem * item, m_items) {
-            item->setGeometry(geometry());
-            item->setPreferredSize(geometry().size());
-        }
-    }
-
-    void removeItem(QGraphicsLayoutItem * item)
-    {
-        m_items.removeAll(item);
-    }
-
-    virtual QGraphicsLayoutItem * itemAt(int i) const
-    {
-        if (i >= 0 && i < m_items.size()) {
-            return m_items.at(i);
-        }
-        return NULL;
-    }
-
-    virtual void removeAt(int i)
-    {
-        if (i >= 0 && i < m_items.size()) {
-            return m_items.removeAt(i);
-        }
-    }
-
-    void addItem(QGraphicsLayoutItem * item)
-    {
-        m_items.append(item);
-    }
-
-    virtual QSizeF sizeHint(Qt::SizeHint hint, const QSizeF & constraint) const
-    {
-        QSizeF size;
-        foreach (QGraphicsLayoutItem * item, m_items) {
-            size.expandedTo(item->effectiveSizeHint(hint, constraint));
-        }
-        return size;
-    }
-private:
-    QList< QGraphicsLayoutItem * > m_items;
-};
-
-LancelotPart::LancelotPart(QObject *parent, const QVariantList &args)
-  : Plasma::Applet(parent, args), m_instance(NULL), m_list(NULL),
-    m_model(NULL), m_icon(NULL), m_dialog(NULL), m_widget(NULL),
-    m_scene(NULL), m_wasConstrained(false)
+LancelotPart::LancelotPart(QObject * parent, const QVariantList &args)
+  : Plasma::PopupApplet(parent, args),
+    m_instance(NULL), m_list(NULL), m_model(NULL),
+    m_icon(NULL)
 {
     if (args.size() > 0) {
         m_cmdarg = args[0].toString();
@@ -163,6 +55,51 @@ LancelotPart::LancelotPart(QObject *parent, const QVariantList &args)
 
     setAcceptDrops(true);
     setHasConfigurationInterface(true);
+    setPopupIcon("lancelot-part");
+    setBackgroundHints(StandardBackground);
+    setAspectRatioMode(Plasma::IgnoreAspectRatio);
+    // setPassivePopup(true);
+
+    foreach (QGraphicsItem * child, childItems()) {
+        Plasma::IconWidget * icon = dynamic_cast < Plasma::IconWidget * > (child);
+        if (icon) {
+            m_icon = icon;
+            m_icon->installEventFilter(this);
+        }
+    }
+
+}
+
+void LancelotPart::init()
+{
+    // Setting up UI
+    m_instance = new Lancelot::Instance();
+    m_list = new Lancelot::ActionListView(this);
+    m_model = new Models::PartsMergedModel();
+    m_list->setModel(m_model);
+    m_instance->activateAll();
+
+    connect(
+            m_model, SIGNAL(removeModelRequested(int)),
+            this, SLOT(removeModel(int))
+    );
+
+    // Loading data
+    bool loaded = loadConfig();
+
+    if (!loaded && !m_cmdarg.isEmpty()) {
+        KFileItem fileItem(KFileItem::Unknown, KFileItem::Unknown, KUrl(m_cmdarg));
+        if (fileItem.mimetype() == "inode/directory") {
+            loadDirectory(m_cmdarg);
+        } else {
+            loadFromFile(m_cmdarg);
+        }
+    }
+
+    m_list->setMinimumSize(150, 200);
+    m_list->setPreferredSize(250, 300);
+    KGlobal::locale()->insertCatalog("lancelot");
+    applyConfig();
 }
 
 void LancelotPart::dragEnterEvent(QGraphicsSceneDragDropEvent * event)
@@ -240,7 +177,6 @@ bool LancelotPart::loadDirectory(const QString & url)
     data["version"]     = "1.0";
     data["type"]        = "list";
     data["model"]       = "Folder " + url;
-    kDebug() << data;
     return load(Serializator::serialize(data));
 }
 
@@ -257,46 +193,6 @@ bool LancelotPart::loadFromList(const QStringList & list)
     return loaded;
 }
 
-void LancelotPart::init()
-{
-    // Setting up UI
-    m_instance = new Lancelot::Instance();
-    m_layout = new FullLayout(this);
-
-    m_list = new Lancelot::ActionListView();
-    m_model = new Models::PartsMergedModel();
-    m_list->setModel(m_model);
-
-    setLayout(m_layout);
-    setupAppletUi(true);
-
-    m_instance->activateAll();
-
-    connect(
-            m_model, SIGNAL(removeModelRequested(int)),
-            this, SLOT(removeModel(int))
-           );
-
-    // Loading data
-    bool loaded = loadConfig();
-    kDebug() << "loaded from config " << loaded;
-    if (!loaded && (m_dialog == NULL)) {
-        kDebug() << "resizing to the default size";
-        resize(200, 300);
-    }
-
-    if (!loaded && !m_cmdarg.isEmpty()) {
-        if (QFileInfo(QUrl(m_cmdarg).toLocalFile()).isDir()) {
-            loadDirectory(m_cmdarg);
-        } else {
-            loadFromFile(m_cmdarg);
-        }
-    }
-
-    resize(size());
-    m_layout->activate();
-}
-
 bool LancelotPart::load(const QString & input)
 {
     QMap < QString, QString > data = Serializator::deserialize(input);
@@ -310,7 +206,7 @@ bool LancelotPart::load(const QString & input)
     if (data["version"] <= "1.0") {
         if (data["type"] == "list") {
             QString modelID = data["model"];
-            Lancelot::ActionListViewModel * model = NULL;
+            Lancelot::ActionListModel * model = NULL;
 
             if (modelID == "Places") {
                 m_model->addModel(modelID, QIcon(), i18n("Places"), model = new Models::Places());
@@ -344,10 +240,18 @@ bool LancelotPart::load(const QString & input)
                 m_model->addModel(modelID, QIcon(), i18n("Favorite Applications"), model = Models::FavoriteApplications::instance());
             } else if (modelID.startsWith("Folder ")) {
                 modelID.remove(0, 7);
-                m_model->addModel(modelID,
+                if (modelID.startsWith("applications:/")) {
+                    modelID.remove(0, 14);
+                    m_model->addModel(modelID,
+                        QIcon(),
+                        modelID,
+                        model = new Models::Applications(modelID, QString(), QIcon(), true));
+                } else {
+                    m_model->addModel(modelID,
                         QIcon(),
                         modelID,
                         model = new Models::FolderModel(modelID));
+                }
                 m_models.append(model);
             }
             loaded = (model != NULL);
@@ -356,7 +260,7 @@ bool LancelotPart::load(const QString & input)
 
     if (loaded) {
         if (!m_data.isEmpty()) {
-            m_data += "\n";
+            m_data += '\n';
         }
         m_data += input;
         saveConfig();
@@ -367,13 +271,7 @@ bool LancelotPart::load(const QString & input)
 
 LancelotPart::~LancelotPart()
 {
-    if (m_dialog != NULL) {
-        ((FullLayout *)m_layout)->removeItem(m_icon);
-        delete m_dialog;
-        delete m_icon;
-    }
-
-    ((FullLayout *)m_layout)->removeItem(m_list);
+    qDeleteAll(m_models);
     delete m_model;
     delete m_instance;
 }
@@ -387,153 +285,72 @@ void LancelotPart::saveConfig()
 
 bool LancelotPart::loadConfig()
 {
+    applyConfig();
+
     KConfigGroup kcg = config();
 
     QString data = kcg.readEntry("partData", QString());
     if (data.isEmpty()) {
         return false;
     }
-    return loadFromList(data.split("\n"));
+    return loadFromList(data.split('\n'));
 }
 
 void LancelotPart::removeModel(int index)
 {
-    Lancelot::ActionListViewModel * model = m_model->modelAt(index);
+    Lancelot::ActionListModel * model = m_model->modelAt(index);
     m_model->removeModel(index);
     if (m_models.contains(model)) {
         delete model;
     }
 
-    QStringList configs = m_data.split("\n");
+    QStringList configs = m_data.split('\n');
     configs.removeAt(index);
     m_data = configs.join("\n");
 
     saveConfig();
 }
 
-void LancelotPart::constraintsEvent(Plasma::Constraints constraints)
+void LancelotPart::timerEvent(QTimerEvent * event)
 {
-    if (constraints & Plasma::FormFactorConstraint) {
-        setupAppletUi();
+    if (event->timerId() == m_timer.timerId()) {
+        m_timer.stop();
+        showPopup();
     }
-
-    m_layout->updateGeometry();
-}
-
-void LancelotPart::setupAppletUi(bool force)
-{
-    bool isSizeConstrained = (
-            (formFactor() != Plasma::Planar) &&
-            (formFactor() != Plasma::MediaCenter)
-            );
-
-    if (!force && (m_wasConstrained == isSizeConstrained)) {
-        return;
-    }
-    m_wasConstrained = isSizeConstrained;
-
-    if (isSizeConstrained) {
-        ((FullLayout *) m_layout)->removeItem(m_list);
-        m_list->setParentItem(NULL);
-
-        if (m_dialog == NULL) {
-            m_dialog = new Plasma::Dialog();
-            m_dialog->setFocusPolicy(Qt::NoFocus);
-            m_dialog->setWindowFlags(Qt::Popup);
-            connect(
-                    Models::ApplicationConnector::instance(), SIGNAL(doHide(bool)),
-                    m_dialog, SLOT(hide())
-                );
-
-            QVBoxLayout * layout = new QVBoxLayout(m_dialog);
-            layout->setSpacing(0);
-            layout->setMargin(0);
-
-            m_scene = new QGraphicsScene(0, 0, 200, 300, m_dialog);
-
-            m_widget = new PopupGraphicsView(m_scene, m_list, m_dialog);
-            layout->addWidget(m_widget);
-
-            m_icon = new Lancelot::HoverIcon(KIcon("lancelot-part"), QString());
-            connect(
-                    m_icon, SIGNAL(activated()),
-                    this, SLOT(iconActivated())
-                   );
-            connect(
-                    m_icon, SIGNAL(clicked()),
-                    this, SLOT(iconActivated())
-                   );
-
-            m_dialog->setLayout(layout);
-            m_dialog->adjustSize();
-
-            m_dialog->installEventFilter(this);
-            m_widget->installEventFilter(this);
-        }
-
-        m_scene->addItem(m_list);
-
-        ((FullLayout *) m_layout)->addItem(m_icon);
-        m_icon->setParentItem(this);
-
-        setAspectRatioMode(Plasma::ConstrainedSquare);
-
-        setMinimumSize(QSizeF());
-    } else {
-        ((FullLayout *) m_layout)->removeItem(m_icon);
-
-        if (m_dialog != NULL) {
-            delete m_dialog;
-            delete m_icon;
-            m_dialog = NULL;
-            m_icon = NULL;
-        }
-        setMinimumSize(QSizeF(150, 200));
-        ((FullLayout *) m_layout)->addItem(m_list);
-        m_list->setParentItem(this);
-        setAspectRatioMode(Plasma::IgnoreAspectRatio);
-    }
-
-    applyConfig();
-}
-
-void LancelotPart::iconActivated()
-{
-    m_dialog->move(popupPosition(m_dialog->sizeHint()));
-    m_dialog->show();
+    PopupApplet::timerEvent(event);
 }
 
 bool LancelotPart::eventFilter(QObject * object, QEvent * event)
 {
-    if (event->type() == QEvent::KeyPress) {
-        QKeyEvent * keyEvent = static_cast<QKeyEvent *>(event);
-        if (keyEvent->key() == Qt::Key_Escape) {
-            hidePopup();
-            return true;
+    if (!m_iconClickActivation && object == m_icon) {
+        if (event->type() == QEvent::QEvent::GraphicsSceneHoverEnter) {
+            m_timer.start(ACTIVATION_TIME, this);
+        } else if (event->type() == QEvent::QEvent::GraphicsSceneHoverLeave) {
+            m_timer.stop();
         }
     }
-    return Plasma::Applet::eventFilter(object, event);
-}
 
-void LancelotPart::hidePopup() {
-    if (m_dialog != NULL) {
-        m_dialog->hide();
-    }
+    return Plasma::PopupApplet::eventFilter(object, event);
 }
 
 void LancelotPart::createConfigurationInterface(KConfigDialog * parent)
 {
     QWidget * widget = new QWidget();
     m_config.setupUi(widget);
-    m_config.panelIcon->setEnabled(m_dialog != NULL);
+    m_config.panelIcon->setVisible(m_list->parentItem() == NULL);
 
     KConfigGroup kcg = config();
-    m_config.setIcon(
-            kcg.readEntry("iconLocation", "lancelot-part"));
+
+    QString iconPath = kcg.readEntry("iconLocation", "lancelot-part");
+    m_config.setIcon(iconPath);
+    if (iconPath == "lancelot-part") {
+        m_config.setIcon(popupIcon());
+    }
+
     m_config.setIconClickActivation(
             kcg.readEntry("iconClickActivation", true));
     m_config.setContentsClickActivation(
-            kcg.readEntry("contentsClickActivation", m_dialog == NULL));
+            kcg.readEntry("contentsClickActivation", m_list->parentItem() == NULL));
     m_config.setContentsExtenderPosition(
             (Lancelot::ExtenderPosition)
             kcg.readEntry("contentsExtenderPosition",
@@ -549,19 +366,24 @@ void LancelotPart::applyConfig()
 {
     KConfigGroup kcg = config();
 
-    if (m_icon != NULL) {
-        m_icon->setActivationMethod(
-                kcg.readEntry("iconClickActivation", true) ?
-                (Lancelot::ClickActivate) : (Lancelot::HoverActivate)
-            );
-        m_icon->setIcon(kcg.readEntry("iconLocation", "lancelot-part"));
-    }
+    QString icon = kcg.readEntry("iconLocation", "lancelot-part");
+    setPopupIcon(icon);
 
-    if (!kcg.readEntry("contentsClickActivation", m_dialog == NULL)) {
-        m_list->setExtenderPosition(
-                (Lancelot::ExtenderPosition)
-                kcg.readEntry("contentsExtenderPosition",
-                (int)Lancelot::RightExtender));
+    if (icon == "lancelot-part") {
+        if (m_model->modelCount() > 0) {
+            Lancelot::ActionListModel * model = m_model->modelAt(0);
+            if (!model->selfIcon().isNull()) {
+                setPopupIcon(model->selfIcon());
+            }
+        }
+    }
+    m_iconClickActivation = kcg.readEntry("iconClickActivation", true);
+
+    if (!kcg.readEntry("contentsClickActivation", m_list->parentItem() == NULL)) {
+       m_list->setExtenderPosition(
+               (Lancelot::ExtenderPosition)
+               kcg.readEntry("contentsExtenderPosition",
+               (int)Lancelot::RightExtender));
     } else {
         m_list->setExtenderPosition(Lancelot::NoExtender);
     }
@@ -584,4 +406,14 @@ void LancelotPart::configAccepted()
     applyConfig();
 }
 
+void LancelotPart::resizeEvent(QGraphicsSceneResizeEvent * event)
+{
+    PopupApplet::resizeEvent(event);
+}
+
+QGraphicsWidget * LancelotPart::graphicsWidget()
+{
+    return m_list;
+}
+
 #include "LancelotPart.moc"
